{-# LANGUAGE TypeApplications #-}


-- | Copyright  : Will Thompson and Iñaki García Etxebarria
-- License    : LGPL-2.1
-- Maintainer : Iñaki García Etxebarria
-- 
-- Represents a link (i.e. a uri).
-- 
-- A widget that contains one or more links should implement
-- the t'GI.Gtk.Interfaces.AccessibleHypertext.AccessibleHypertext' interface and return
-- @GtkAccessibleHyperlink@ objects for each of the links.
-- 
-- /Since: 4.22/

#if (MIN_VERSION_haskell_gi_overloading(1,0,0) && !defined(__HADDOCK_VERSION__))
#define ENABLE_OVERLOADING
#endif

module GI.Gtk.Objects.AccessibleHyperlink
    ( 

-- * Exported types
    AccessibleHyperlink(..)                 ,
    IsAccessibleHyperlink                   ,
    toAccessibleHyperlink                   ,


 -- * Methods
-- | 
-- 
--  === __Click to display all available methods, including inherited ones__
-- ==== Methods
-- [announce]("GI.Gtk.Interfaces.Accessible#g:method:announce"), [bindProperty]("GI.GObject.Objects.Object#g:method:bindProperty"), [bindPropertyFull]("GI.GObject.Objects.Object#g:method:bindPropertyFull"), [forceFloating]("GI.GObject.Objects.Object#g:method:forceFloating"), [freezeNotify]("GI.GObject.Objects.Object#g:method:freezeNotify"), [getv]("GI.GObject.Objects.Object#g:method:getv"), [isFloating]("GI.GObject.Objects.Object#g:method:isFloating"), [notify]("GI.GObject.Objects.Object#g:method:notify"), [notifyByPspec]("GI.GObject.Objects.Object#g:method:notifyByPspec"), [ref]("GI.GObject.Objects.Object#g:method:ref"), [refSink]("GI.GObject.Objects.Object#g:method:refSink"), [resetProperty]("GI.Gtk.Interfaces.Accessible#g:method:resetProperty"), [resetRelation]("GI.Gtk.Interfaces.Accessible#g:method:resetRelation"), [resetState]("GI.Gtk.Interfaces.Accessible#g:method:resetState"), [runDispose]("GI.GObject.Objects.Object#g:method:runDispose"), [stealData]("GI.GObject.Objects.Object#g:method:stealData"), [stealQdata]("GI.GObject.Objects.Object#g:method:stealQdata"), [thawNotify]("GI.GObject.Objects.Object#g:method:thawNotify"), [unref]("GI.GObject.Objects.Object#g:method:unref"), [updateNextAccessibleSibling]("GI.Gtk.Interfaces.Accessible#g:method:updateNextAccessibleSibling"), [updatePlatformState]("GI.Gtk.Interfaces.Accessible#g:method:updatePlatformState"), [updateProperty]("GI.Gtk.Interfaces.Accessible#g:method:updateProperty"), [updateRelation]("GI.Gtk.Interfaces.Accessible#g:method:updateRelation"), [updateState]("GI.Gtk.Interfaces.Accessible#g:method:updateState"), [watchClosure]("GI.GObject.Objects.Object#g:method:watchClosure").
-- 
-- ==== Getters
-- [getAccessibleId]("GI.Gtk.Interfaces.Accessible#g:method:getAccessibleId"), [getAccessibleParent]("GI.Gtk.Interfaces.Accessible#g:method:getAccessibleParent"), [getAccessibleRole]("GI.Gtk.Interfaces.Accessible#g:method:getAccessibleRole"), [getAtContext]("GI.Gtk.Interfaces.Accessible#g:method:getAtContext"), [getBounds]("GI.Gtk.Interfaces.Accessible#g:method:getBounds"), [getData]("GI.GObject.Objects.Object#g:method:getData"), [getFirstAccessibleChild]("GI.Gtk.Interfaces.Accessible#g:method:getFirstAccessibleChild"), [getNextAccessibleSibling]("GI.Gtk.Interfaces.Accessible#g:method:getNextAccessibleSibling"), [getPlatformState]("GI.Gtk.Interfaces.Accessible#g:method:getPlatformState"), [getProperty]("GI.GObject.Objects.Object#g:method:getProperty"), [getQdata]("GI.GObject.Objects.Object#g:method:getQdata").
-- 
-- ==== Setters
-- [setAccessibleParent]("GI.Gtk.Interfaces.Accessible#g:method:setAccessibleParent"), [setData]("GI.GObject.Objects.Object#g:method:setData"), [setDataFull]("GI.GObject.Objects.Object#g:method:setDataFull"), [setPlatformState]("GI.Gtk.Objects.AccessibleHyperlink#g:method:setPlatformState"), [setProperty]("GI.GObject.Objects.Object#g:method:setProperty").

#if defined(ENABLE_OVERLOADING)
    ResolveAccessibleHyperlinkMethod        ,
#endif

-- ** new #method:new#

    accessibleHyperlinkNew                  ,


-- ** setPlatformState #method:setPlatformState#

#if defined(ENABLE_OVERLOADING)
    AccessibleHyperlinkSetPlatformStateMethodInfo,
#endif
    accessibleHyperlinkSetPlatformState     ,




    ) where

import Data.GI.Base.ShortPrelude
import qualified Data.GI.Base.ShortPrelude as SP
import qualified Data.GI.Base.Overloading as O
import qualified Prelude as P

import qualified Data.GI.Base.Attributes as GI.Attributes
import qualified Data.GI.Base.BasicTypes as B.Types
import qualified Data.GI.Base.ManagedPtr as B.ManagedPtr
import qualified Data.GI.Base.GArray as B.GArray
import qualified Data.GI.Base.GClosure as B.GClosure
import qualified Data.GI.Base.GError as B.GError
import qualified Data.GI.Base.GHashTable as B.GHT
import qualified Data.GI.Base.GVariant as B.GVariant
import qualified Data.GI.Base.GValue as B.GValue
import qualified Data.GI.Base.GParamSpec as B.GParamSpec
import qualified Data.GI.Base.CallStack as B.CallStack
import qualified Data.GI.Base.Properties as B.Properties
import qualified Data.GI.Base.Signals as B.Signals
import qualified Control.Monad.IO.Class as MIO
import qualified Data.Coerce as Coerce
import qualified Data.Text as T
import qualified Data.Kind as DK
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map
import qualified Foreign.Ptr as FP
import qualified GHC.OverloadedLabels as OL
import qualified GHC.Records as R
import qualified Data.Word as DW
import qualified Data.Int as DI
import qualified System.Posix.Types as SPT
import qualified Foreign.C.Types as FCT

-- Workaround for https://gitlab.haskell.org/ghc/ghc/-/issues/23392
#if MIN_VERSION_base(4,18,0)
import qualified GI.GObject.Objects.Object as GObject.Object
import qualified GI.Gdk.Objects.Display as Gdk.Display
import {-# SOURCE #-} qualified GI.Gtk.Enums as Gtk.Enums
import {-# SOURCE #-} qualified GI.Gtk.Interfaces.Accessible as Gtk.Accessible
import {-# SOURCE #-} qualified GI.Gtk.Interfaces.AccessibleHypertext as Gtk.AccessibleHypertext
import {-# SOURCE #-} qualified GI.Gtk.Objects.ATContext as Gtk.ATContext
import {-# SOURCE #-} qualified GI.Gtk.Structs.AccessibleTextRange as Gtk.AccessibleTextRange

#else
import qualified GI.GObject.Objects.Object as GObject.Object
import {-# SOURCE #-} qualified GI.Gtk.Enums as Gtk.Enums
import {-# SOURCE #-} qualified GI.Gtk.Interfaces.Accessible as Gtk.Accessible
import {-# SOURCE #-} qualified GI.Gtk.Interfaces.AccessibleHypertext as Gtk.AccessibleHypertext
import {-# SOURCE #-} qualified GI.Gtk.Structs.AccessibleTextRange as Gtk.AccessibleTextRange

#endif

-- | Memory-managed wrapper type.
newtype AccessibleHyperlink = AccessibleHyperlink (SP.ManagedPtr AccessibleHyperlink)
    deriving (Eq)

instance SP.ManagedPtrNewtype AccessibleHyperlink where
    toManagedPtr (AccessibleHyperlink p) = p

foreign import ccall "gtk_accessible_hyperlink_get_type"
    c_gtk_accessible_hyperlink_get_type :: IO B.Types.GType

instance B.Types.TypedObject AccessibleHyperlink where
    glibType = c_gtk_accessible_hyperlink_get_type

instance B.Types.GObject AccessibleHyperlink

-- | Type class for types which can be safely cast to t'AccessibleHyperlink', for instance with `toAccessibleHyperlink`.
class (SP.GObject o, O.IsDescendantOf AccessibleHyperlink o) => IsAccessibleHyperlink o
instance (SP.GObject o, O.IsDescendantOf AccessibleHyperlink o) => IsAccessibleHyperlink o

instance O.HasParentTypes AccessibleHyperlink
type instance O.ParentTypes AccessibleHyperlink = '[GObject.Object.Object, Gtk.Accessible.Accessible]

-- | Cast to t'AccessibleHyperlink', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
toAccessibleHyperlink :: (MIO.MonadIO m, IsAccessibleHyperlink o) => o -> m AccessibleHyperlink
toAccessibleHyperlink = MIO.liftIO . B.ManagedPtr.unsafeCastTo AccessibleHyperlink

-- | Convert t'AccessibleHyperlink' to and from t'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
instance B.GValue.IsGValue (Maybe AccessibleHyperlink) where
    gvalueGType_ = c_gtk_accessible_hyperlink_get_type
    gvalueSet_ gv P.Nothing = B.GValue.set_object gv (FP.nullPtr :: FP.Ptr AccessibleHyperlink)
    gvalueSet_ gv (P.Just obj) = B.ManagedPtr.withManagedPtr obj (B.GValue.set_object gv)
    gvalueGet_ gv = do
        ptr <- B.GValue.get_object gv :: IO (FP.Ptr AccessibleHyperlink)
        if ptr /= FP.nullPtr
        then P.Just <$> B.ManagedPtr.newObject AccessibleHyperlink ptr
        else return P.Nothing
        
    

#if defined(ENABLE_OVERLOADING)
type family ResolveAccessibleHyperlinkMethod (t :: Symbol) (o :: DK.Type) :: DK.Type where
    ResolveAccessibleHyperlinkMethod "announce" o = Gtk.Accessible.AccessibleAnnounceMethodInfo
    ResolveAccessibleHyperlinkMethod "bindProperty" o = GObject.Object.ObjectBindPropertyMethodInfo
    ResolveAccessibleHyperlinkMethod "bindPropertyFull" o = GObject.Object.ObjectBindPropertyFullMethodInfo
    ResolveAccessibleHyperlinkMethod "forceFloating" o = GObject.Object.ObjectForceFloatingMethodInfo
    ResolveAccessibleHyperlinkMethod "freezeNotify" o = GObject.Object.ObjectFreezeNotifyMethodInfo
    ResolveAccessibleHyperlinkMethod "getv" o = GObject.Object.ObjectGetvMethodInfo
    ResolveAccessibleHyperlinkMethod "isFloating" o = GObject.Object.ObjectIsFloatingMethodInfo
    ResolveAccessibleHyperlinkMethod "notify" o = GObject.Object.ObjectNotifyMethodInfo
    ResolveAccessibleHyperlinkMethod "notifyByPspec" o = GObject.Object.ObjectNotifyByPspecMethodInfo
    ResolveAccessibleHyperlinkMethod "ref" o = GObject.Object.ObjectRefMethodInfo
    ResolveAccessibleHyperlinkMethod "refSink" o = GObject.Object.ObjectRefSinkMethodInfo
    ResolveAccessibleHyperlinkMethod "resetProperty" o = Gtk.Accessible.AccessibleResetPropertyMethodInfo
    ResolveAccessibleHyperlinkMethod "resetRelation" o = Gtk.Accessible.AccessibleResetRelationMethodInfo
    ResolveAccessibleHyperlinkMethod "resetState" o = Gtk.Accessible.AccessibleResetStateMethodInfo
    ResolveAccessibleHyperlinkMethod "runDispose" o = GObject.Object.ObjectRunDisposeMethodInfo
    ResolveAccessibleHyperlinkMethod "stealData" o = GObject.Object.ObjectStealDataMethodInfo
    ResolveAccessibleHyperlinkMethod "stealQdata" o = GObject.Object.ObjectStealQdataMethodInfo
    ResolveAccessibleHyperlinkMethod "thawNotify" o = GObject.Object.ObjectThawNotifyMethodInfo
    ResolveAccessibleHyperlinkMethod "unref" o = GObject.Object.ObjectUnrefMethodInfo
    ResolveAccessibleHyperlinkMethod "updateNextAccessibleSibling" o = Gtk.Accessible.AccessibleUpdateNextAccessibleSiblingMethodInfo
    ResolveAccessibleHyperlinkMethod "updatePlatformState" o = Gtk.Accessible.AccessibleUpdatePlatformStateMethodInfo
    ResolveAccessibleHyperlinkMethod "updateProperty" o = Gtk.Accessible.AccessibleUpdatePropertyMethodInfo
    ResolveAccessibleHyperlinkMethod "updateRelation" o = Gtk.Accessible.AccessibleUpdateRelationMethodInfo
    ResolveAccessibleHyperlinkMethod "updateState" o = Gtk.Accessible.AccessibleUpdateStateMethodInfo
    ResolveAccessibleHyperlinkMethod "watchClosure" o = GObject.Object.ObjectWatchClosureMethodInfo
    ResolveAccessibleHyperlinkMethod "getAccessibleId" o = Gtk.Accessible.AccessibleGetAccessibleIdMethodInfo
    ResolveAccessibleHyperlinkMethod "getAccessibleParent" o = Gtk.Accessible.AccessibleGetAccessibleParentMethodInfo
    ResolveAccessibleHyperlinkMethod "getAccessibleRole" o = Gtk.Accessible.AccessibleGetAccessibleRoleMethodInfo
    ResolveAccessibleHyperlinkMethod "getAtContext" o = Gtk.Accessible.AccessibleGetAtContextMethodInfo
    ResolveAccessibleHyperlinkMethod "getBounds" o = Gtk.Accessible.AccessibleGetBoundsMethodInfo
    ResolveAccessibleHyperlinkMethod "getData" o = GObject.Object.ObjectGetDataMethodInfo
    ResolveAccessibleHyperlinkMethod "getFirstAccessibleChild" o = Gtk.Accessible.AccessibleGetFirstAccessibleChildMethodInfo
    ResolveAccessibleHyperlinkMethod "getNextAccessibleSibling" o = Gtk.Accessible.AccessibleGetNextAccessibleSiblingMethodInfo
    ResolveAccessibleHyperlinkMethod "getPlatformState" o = Gtk.Accessible.AccessibleGetPlatformStateMethodInfo
    ResolveAccessibleHyperlinkMethod "getProperty" o = GObject.Object.ObjectGetPropertyMethodInfo
    ResolveAccessibleHyperlinkMethod "getQdata" o = GObject.Object.ObjectGetQdataMethodInfo
    ResolveAccessibleHyperlinkMethod "setAccessibleParent" o = Gtk.Accessible.AccessibleSetAccessibleParentMethodInfo
    ResolveAccessibleHyperlinkMethod "setData" o = GObject.Object.ObjectSetDataMethodInfo
    ResolveAccessibleHyperlinkMethod "setDataFull" o = GObject.Object.ObjectSetDataFullMethodInfo
    ResolveAccessibleHyperlinkMethod "setPlatformState" o = AccessibleHyperlinkSetPlatformStateMethodInfo
    ResolveAccessibleHyperlinkMethod "setProperty" o = GObject.Object.ObjectSetPropertyMethodInfo
    ResolveAccessibleHyperlinkMethod l o = O.MethodResolutionFailed l o

instance (info ~ ResolveAccessibleHyperlinkMethod t AccessibleHyperlink, O.OverloadedMethod info AccessibleHyperlink p) => OL.IsLabel t (AccessibleHyperlink -> p) where
#if MIN_VERSION_base(4,10,0)
    fromLabel = O.overloadedMethod @info
#else
    fromLabel _ = O.overloadedMethod @info
#endif

#if MIN_VERSION_base(4,13,0)
instance (info ~ ResolveAccessibleHyperlinkMethod t AccessibleHyperlink, O.OverloadedMethod info AccessibleHyperlink p, R.HasField t AccessibleHyperlink p) => R.HasField t AccessibleHyperlink p where
    getField = O.overloadedMethod @info

#endif

instance (info ~ ResolveAccessibleHyperlinkMethod t AccessibleHyperlink, O.OverloadedMethodInfo info AccessibleHyperlink) => OL.IsLabel t (O.MethodProxy info AccessibleHyperlink) where
#if MIN_VERSION_base(4,10,0)
    fromLabel = O.MethodProxy
#else
    fromLabel _ = O.MethodProxy
#endif

#endif

#if defined(ENABLE_OVERLOADING)
instance O.HasAttributeList AccessibleHyperlink
type instance O.AttributeList AccessibleHyperlink = AccessibleHyperlinkAttributeList
type AccessibleHyperlinkAttributeList = ('[ '("accessibleRole", Gtk.Accessible.AccessibleAccessibleRolePropertyInfo)] :: [(Symbol, DK.Type)])
#endif

#if defined(ENABLE_OVERLOADING)
#endif

#if defined(ENABLE_OVERLOADING)
type instance O.SignalList AccessibleHyperlink = AccessibleHyperlinkSignalList
type AccessibleHyperlinkSignalList = ('[ '("notify", GObject.Object.ObjectNotifySignalInfo)] :: [(Symbol, DK.Type)])

#endif

-- method AccessibleHyperlink::new
-- method type : Constructor
-- Args: [ Arg
--           { argCName = "parent"
--           , argType =
--               TInterface
--                 Name { namespace = "Gtk" , name = "AccessibleHypertext" }
--           , argCType = Just "GtkAccessibleHypertext*"
--           , direction = DirectionIn
--           , mayBeNull = False
--           , argDoc =
--               Documentation
--                 { rawDocText = Just "the parent" , sinceVersion = Nothing }
--           , argScope = ScopeTypeInvalid
--           , argClosure = -1
--           , argDestroy = -1
--           , argCallerAllocates = False
--           , argCallbackUserData = False
--           , transfer = TransferNothing
--           }
--       , Arg
--           { argCName = "index"
--           , argType = TBasicType TUInt
--           , argCType = Just "unsigned int"
--           , direction = DirectionIn
--           , mayBeNull = False
--           , argDoc =
--               Documentation
--                 { rawDocText = Just "the index of this link in the parent"
--                 , sinceVersion = Nothing
--                 }
--           , argScope = ScopeTypeInvalid
--           , argClosure = -1
--           , argDestroy = -1
--           , argCallerAllocates = False
--           , argCallbackUserData = False
--           , transfer = TransferNothing
--           }
--       , Arg
--           { argCName = "uri"
--           , argType = TBasicType TUTF8
--           , argCType = Just "const char*"
--           , direction = DirectionIn
--           , mayBeNull = False
--           , argDoc =
--               Documentation
--                 { rawDocText = Just "the uri" , sinceVersion = Nothing }
--           , argScope = ScopeTypeInvalid
--           , argClosure = -1
--           , argDestroy = -1
--           , argCallerAllocates = False
--           , argCallbackUserData = False
--           , transfer = TransferNothing
--           }
--       , Arg
--           { argCName = "bounds"
--           , argType =
--               TInterface
--                 Name { namespace = "Gtk" , name = "AccessibleTextRange" }
--           , argCType = Just "GtkAccessibleTextRange*"
--           , direction = DirectionIn
--           , mayBeNull = False
--           , argDoc =
--               Documentation
--                 { rawDocText =
--                     Just "the text range that the link occupies (or 0, 0)"
--                 , sinceVersion = Nothing
--                 }
--           , argScope = ScopeTypeInvalid
--           , argClosure = -1
--           , argDestroy = -1
--           , argCallerAllocates = False
--           , argCallbackUserData = False
--           , transfer = TransferNothing
--           }
--       ]
-- Lengths: []
-- returnType: Just
--               (TInterface
--                  Name { namespace = "Gtk" , name = "AccessibleHyperlink" })
-- throws : False
-- Skip return : False

foreign import ccall "gtk_accessible_hyperlink_new" gtk_accessible_hyperlink_new :: 
    Ptr Gtk.AccessibleHypertext.AccessibleHypertext -> -- parent : TInterface (Name {namespace = "Gtk", name = "AccessibleHypertext"})
    Word32 ->                               -- index : TBasicType TUInt
    CString ->                              -- uri : TBasicType TUTF8
    Ptr Gtk.AccessibleTextRange.AccessibleTextRange -> -- bounds : TInterface (Name {namespace = "Gtk", name = "AccessibleTextRange"})
    IO (Ptr AccessibleHyperlink)

-- | Creates an accessible object that represents a hyperlink.
-- 
-- This is meant to be used with an implementation of the
-- t'GI.Gtk.Interfaces.AccessibleHypertext.AccessibleHypertext' interface.
-- 
-- /Since: 4.22/
accessibleHyperlinkNew ::
    (B.CallStack.HasCallStack, MonadIO m, Gtk.AccessibleHypertext.IsAccessibleHypertext a) =>
    a
    -- ^ /@parent@/: the parent
    -> Word32
    -- ^ /@index@/: the index of this link in the parent
    -> T.Text
    -- ^ /@uri@/: the uri
    -> Gtk.AccessibleTextRange.AccessibleTextRange
    -- ^ /@bounds@/: the text range that the link occupies (or 0, 0)
    -> m AccessibleHyperlink
accessibleHyperlinkNew parent index uri bounds = liftIO $ do
    parent' <- unsafeManagedPtrCastPtr parent
    uri' <- textToCString uri
    bounds' <- unsafeManagedPtrGetPtr bounds
    result <- gtk_accessible_hyperlink_new parent' index uri' bounds'
    checkUnexpectedReturnNULL "accessibleHyperlinkNew" result
    result' <- (wrapObject AccessibleHyperlink) result
    touchManagedPtr parent
    touchManagedPtr bounds
    freeMem uri'
    return result'

#if defined(ENABLE_OVERLOADING)
#endif

-- method AccessibleHyperlink::set_platform_state
-- method type : OrdinaryMethod
-- Args: [ Arg
--           { argCName = "self"
--           , argType =
--               TInterface
--                 Name { namespace = "Gtk" , name = "AccessibleHyperlink" }
--           , argCType = Just "GtkAccessibleHyperlink*"
--           , direction = DirectionIn
--           , mayBeNull = False
--           , argDoc =
--               Documentation
--                 { rawDocText = Just "the accessible" , sinceVersion = Nothing }
--           , argScope = ScopeTypeInvalid
--           , argClosure = -1
--           , argDestroy = -1
--           , argCallerAllocates = False
--           , argCallbackUserData = False
--           , transfer = TransferNothing
--           }
--       , Arg
--           { argCName = "state"
--           , argType =
--               TInterface
--                 Name { namespace = "Gtk" , name = "AccessiblePlatformState" }
--           , argCType = Just "GtkAccessiblePlatformState"
--           , direction = DirectionIn
--           , mayBeNull = False
--           , argDoc =
--               Documentation
--                 { rawDocText = Just "the platform state to change"
--                 , sinceVersion = Nothing
--                 }
--           , argScope = ScopeTypeInvalid
--           , argClosure = -1
--           , argDestroy = -1
--           , argCallerAllocates = False
--           , argCallbackUserData = False
--           , transfer = TransferNothing
--           }
--       , Arg
--           { argCName = "enabled"
--           , argType = TBasicType TBoolean
--           , argCType = Just "gboolean"
--           , direction = DirectionIn
--           , mayBeNull = False
--           , argDoc =
--               Documentation
--                 { rawDocText = Just "the new value for the platform state"
--                 , sinceVersion = Nothing
--                 }
--           , argScope = ScopeTypeInvalid
--           , argClosure = -1
--           , argDestroy = -1
--           , argCallerAllocates = False
--           , argCallbackUserData = False
--           , transfer = TransferNothing
--           }
--       ]
-- Lengths: []
-- returnType: Nothing
-- throws : False
-- Skip return : False

foreign import ccall "gtk_accessible_hyperlink_set_platform_state" gtk_accessible_hyperlink_set_platform_state :: 
    Ptr AccessibleHyperlink ->              -- self : TInterface (Name {namespace = "Gtk", name = "AccessibleHyperlink"})
    CUInt ->                                -- state : TInterface (Name {namespace = "Gtk", name = "AccessiblePlatformState"})
    CInt ->                                 -- enabled : TBasicType TBoolean
    IO ()

-- | Sets a platform state on the accessible.
-- 
-- /Since: 4.22/
accessibleHyperlinkSetPlatformState ::
    (B.CallStack.HasCallStack, MonadIO m, IsAccessibleHyperlink a) =>
    a
    -- ^ /@self@/: the accessible
    -> Gtk.Enums.AccessiblePlatformState
    -- ^ /@state@/: the platform state to change
    -> Bool
    -- ^ /@enabled@/: the new value for the platform state
    -> m ()
accessibleHyperlinkSetPlatformState self state enabled = liftIO $ do
    self' <- unsafeManagedPtrCastPtr self
    let state' = (fromIntegral . fromEnum) state
    let enabled' = (P.fromIntegral . P.fromEnum) enabled
    gtk_accessible_hyperlink_set_platform_state self' state' enabled'
    touchManagedPtr self
    return ()

#if defined(ENABLE_OVERLOADING)
data AccessibleHyperlinkSetPlatformStateMethodInfo
instance (signature ~ (Gtk.Enums.AccessiblePlatformState -> Bool -> m ()), MonadIO m, IsAccessibleHyperlink a) => O.OverloadedMethod AccessibleHyperlinkSetPlatformStateMethodInfo a signature where
    overloadedMethod = accessibleHyperlinkSetPlatformState

instance O.OverloadedMethodInfo AccessibleHyperlinkSetPlatformStateMethodInfo a where
    overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
        O.resolvedSymbolName = "GI.Gtk.Objects.AccessibleHyperlink.accessibleHyperlinkSetPlatformState",
        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-AccessibleHyperlink.html#v:accessibleHyperlinkSetPlatformState"
        })


#endif


